.. nodoctest

Graph-directed iterated function system (GIFS)
==============================================

.. automodule:: slabbe.graph_directed_IFS
   :members:
   :undoc-members:
   :show-inheritance:
   

